Uploaded sanitized BC250/ROCm Repository.

This commit is contained in:
Fabian
2026-08-20 00:45:43 +02:00
parent 7d2184f1e8
commit d7d22e93b3
678 changed files with 65963 additions and 1 deletions
@@ -0,0 +1,15 @@
#!/bin/bash
cat > /tmp/test_arch.hip << 'HIPEOF'
#include <hip/hip_runtime.h>
__global__ void test_kernel(float *a) { a[threadIdx.x] = 1.0f; }
HIPEOF
for arch in gfx1013 gfx1010 gfx10-1-generic; do
echo "=== Testing $arch ==="
/opt/rocm/bin/hipcc --offload-arch=$arch -c /tmp/test_arch.hip -o /tmp/test_${arch}.o 2>&1
echo "Exit: $?"
if [ -f /tmp/test_${arch}.o ]; then
ls -l /tmp/test_${arch}.o
fi
echo ""
done